@@ -6,7 +6,7 @@ from django.db import models
 from django.db.models.query import QuerySet
 from django.conf import settings
 from django.utils.functional import cached_property
-
+from django.utils.translation import gettext_lazy as _
 from dynamic_preferences.registries import preference_models, global_preferences_registry
 from .utils import update
 
@@ -19,13 +19,13 @@ class BasePreferenceModel(models.Model):
 
     #: The section under which the preference is declared
     section = models.CharField(
-        max_length=150, db_index=True, blank=True, null=True, default=None)
+        max_length=150, db_index=True, blank=True, null=True, default=None, verbose_name=_('Section Name'))
 
     #: a name for the preference
-    name = models.CharField(max_length=150, db_index=True)
+    name = models.CharField(_("Name"), max_length=150, db_index=True)
 
     #: a value, serialized to a string. This field should not be accessed directly, use :py:attr:`BasePreferenceModel.value` instead
-    raw_value = models.TextField(null=True, blank=True)
+    raw_value = models.TextField(_("Raw Value"), null=True, blank=True)
 
     class Meta:
         abstract = True
@@ -39,10 +39,12 @@ class BasePreferenceModel(models.Model):
     @property
     def verbose_name(self):
         return self.preference.get('verbose_name', self.preference.identifier)
+    verbose_name.fget.short_description = _('Verbose Name')
 
     @property
     def help_text(self):
         return self.preference.get('help_text', '')
+    help_text.fget.short_description = _('Help Text')
 
     def set_value(self, value):
         """
@@ -79,8 +81,8 @@ class GlobalPreferenceModel(BasePreferenceModel):
         unique_together = ('section', 'name')
         app_label = 'dynamic_preferences'
 
-        verbose_name = "global preference"
-        verbose_name_plural = "global preferences"
+        verbose_name = _("Global preference")
+        verbose_name_plural = _("Global preferences")
 
 
 class PerInstancePreferenceModel(BasePreferenceModel):
@@ -96,11 +98,7 @@ class PerInstancePreferenceModel(BasePreferenceModel):
 
     @classmethod
     def get_instance_model(cls):
-        return cls._meta.get_field('instance').rel.to
-
-    @property
-    def registry(self):
-        return preference_models.get_by_instance(self.instance)
+        return cls._meta.get_field('instance').remote_field.model
 
 
 global_preferences_registry.preference_model = GlobalPreferenceModel
@@ -110,17 +108,6 @@ global_preferences_registry.preference_model = GlobalPreferenceModel
 from django.db.models.signals import post_save
 
 
-def create_default_per_instance_preferences(sender, created, instance, **kwargs):
-    """Create default preferences for PerInstancePreferenceModel"""
-
-    if created:
-        try:
-            registry = preference_models.get_by_instance(instance)
-            registry.create_default_preferences(instance)
-        except AttributeError:
-            pass
-
-
 def invalidate_cache(sender, created, instance, **kwargs):
     if not isinstance(instance, BasePreferenceModel):
         return
@@ -133,5 +120,4 @@ def invalidate_cache(sender, created, instance, **kwargs):
     manager = registry.manager(**kwargs)
     manager.to_cache(instance)
 
-post_save.connect(create_default_per_instance_preferences)
 post_save.connect(invalidate_cache)
