@@ -1,4 +1,4 @@
-from django.db.models.fields import FieldDoesNotExist
+from django.core.exceptions import FieldDoesNotExist
 from django.apps import apps
 # import the logging library
 import warnings
@@ -36,7 +36,8 @@ class PreferenceModelsRegistry(persisting_theory.Registry):
     def register(self, preference_model, preference_registry):
         self[preference_model] = preference_registry
         preference_registry.preference_model = preference_model
-
+        if not hasattr(preference_model, 'registry'):
+            setattr(preference_model, 'registry', preference_registry)
         self.attach_manager(preference_model, preference_registry)
 
     def attach_manager(self, model, registry):
@@ -47,11 +48,14 @@ class PreferenceModelsRegistry(persisting_theory.Registry):
             return registry.manager(instance=self)
 
         getter = property(instance_getter)
-        instance_class = model._meta.get_field('instance').rel.to
+        instance_class = model._meta.get_field('instance').remote_field.model
         setattr(instance_class, preferences_settings.MANAGER_ATTRIBUTE, getter)
 
     def get_by_preference(self, preference):
-        return self[preference.__class__]
+        return self[
+            preference._meta.proxy_for_model if preference._meta.proxy
+            else preference.__class__
+        ]
 
     def get_by_instance(self, instance):
         """Return a preference registry using a model instance"""
@@ -59,7 +63,7 @@ class PreferenceModelsRegistry(persisting_theory.Registry):
         # and check if instance is and instance of this class
         for model, registry in self.items():
             try:
-                instance_class = model._meta.get_field('instance').rel.to
+                instance_class = model._meta.get_field('instance').remote_field.model
                 if isinstance(instance, instance_class):
                     return registry
 
@@ -91,6 +95,13 @@ class PreferenceRegistry(persisting_theory.Registry):
     name = "preferences_registry"
     preference_model = None
 
+    #: used to reverse urls for sections in form views/templates
+    section_url_namespace = None
+
+    def __init__(self, *args, **kwargs):
+        super(PreferenceRegistry, self).__init__(*args, **kwargs)
+        self.section_objects = collections.OrderedDict()
+
     def register(self, preference_class):
         """
         Store the given preference class in the registry.
@@ -98,6 +109,8 @@ class PreferenceRegistry(persisting_theory.Registry):
         :param preference_class: a :py:class:`prefs.Preference` subclass
         """
         preference = preference_class(registry=self)
+        self.section_objects[preference.section.name] = preference.section
+
         try:
             self[preference.section.name][preference.name] = preference
 
@@ -161,7 +174,6 @@ class PreferenceRegistry(persisting_theory.Registry):
             raise NotFoundInRegistry("No such preference in {0} with section={1} and name={2}".format(
                 self.__class__.__name__, section, name))
 
-
     def get_by_name(self, name):
         """Get a preference by name only (no section)"""
         for section in self.values():
@@ -169,7 +181,8 @@ class PreferenceRegistry(persisting_theory.Registry):
                 if preference.name == name:
                     return preference
         raise NotFoundInRegistry("No such preference in {0} with name={1}".format(
-            name))
+            self.__class__.__name__, name))
+
     def manager(self, **kwargs):
         """Return a preference manager that can be used to retrieve preference values"""
         return PreferencesManager(registry=self, model=self.preference_model, **kwargs)
@@ -203,6 +216,8 @@ class PerInstancePreferenceRegistry(PreferenceRegistry):
 
 
 class GlobalPreferenceRegistry(PreferenceRegistry):
+    section_url_namespace = 'dynamic_preferences:global.section'
+
     def populate(self, **kwargs):
         return self.models(**kwargs)
 
