@@ -1,5 +1,6 @@
 from django.apps import AppConfig, apps
 from django.conf import settings
+from django.utils.translation import gettext_lazy as _
 
 from ..registries import preference_models
 from .registries import user_preferences_registry
@@ -7,7 +8,7 @@ from .registries import user_preferences_registry
 
 class UserPreferencesConfig(AppConfig):
     name = 'dynamic_preferences.users'
-    verbose_name = "Preferences - Users"
+    verbose_name = _("Preferences - Users")
     label = 'dynamic_preferences_users'
 
     def ready(self):
