@@ -2,7 +2,7 @@ from ..registries import PerInstancePreferenceRegistry
 
 
 class UserPreferenceRegistry(PerInstancePreferenceRegistry):
-    pass
+    section_url_namespace = 'dynamic_preferences:user.section'
 
 
 user_preferences_registry = UserPreferenceRegistry()
